qipipe - OHSU QIN pipeline
==========================

OHSU QIN Quantitative Imaging pipelines.
See the `documentation`_ for more information.

.. Targets:

.. _documentation: http://quip1.ohsu.edu:8080/qipipe
